import React, {useEffect, useState} from 'react';
import {Button, Form, Message, TextArea} from 'semantic-ui-react';
import {API_BASE_URL} from "../../../config";
import {post, put} from "../../../services/request";
import {useNavigate} from 'react-router-dom';
import Errors from "../../../components/Errors/Errors";

const ArticleForm = ({article}) => {
    const [state, setState] = useState( {
        article,
        title: null,
        content: null,
        isLoading: false,
        errorMessage: null,
        errors: null,
        error: null
    });
    const navigate = useNavigate();

    const handleSubmit = (e) => {
        e.preventDefault();
        setState(prevState => ({...prevState, isLoading: true}));
        const token = localStorage.getItem('token');
        const user = JSON.parse(localStorage.getItem('user'));
        const data = {
            title: state.title,
            content: state.content,
            user_id: user.id
        };
        if (state.article) {
            put(API_BASE_URL + `/articles/${state.article.id}`, data, token)
                .then(response => {
                    if (Object.keys(response).includes('data')) {
                        return navigate('/articles');
                    } else if (Object.keys(response).includes('error')) {
                        setState(prevState => ({...prevState, error: response.error}));
                    } else {
                        setState(prevState => ({...prevState, error: response.error, errorMessage: response.message,}));
                    }
                });
        } else {
            post(API_BASE_URL + "/articles", data, token)
                .then(response => {
                    if (Object.keys(response).includes('data')) {
                        return navigate('/articles');
                    } else if (Object.keys(response).includes('error')) {
                        setState(prevState => ({...prevState, error: response.error}));
                    } else {
                        setState(prevState => ({...prevState, error: response.error, errorMessage: response.message,}));
                    }
                });
        }

        setState(prevState => ({...prevState, isLoading: false}));
    };

    useEffect(() => {
        if (article) {
            setState(prevState => ({
                ...prevState,
                title: article.title,
                content: article.content
            }));
        }
    }, [article]);

    const onChangeInputHandler = e => {
        const {name, value} = e.currentTarget;

        setState(prevState => ({
            ...prevState,
            [name]: value,
            errors: null
        }));
    };

    return (
        <div>
            {state.error && <Message negative><Message.Header>{this.state.error}</Message.Header></Message>}
            {state.errors && <Errors errors={state.errors} errorMessage={state.errorMessage} />}
            <Form>
                <Form.Field>
                    <label>Title</label>
                    <input type="text" placeholder='Title' value={state.title || ''} name='title'
                           onChange={onChangeInputHandler}
                    />
                </Form.Field>
                <Form.Field>
                    <label>Content</label>
                    <TextArea value={state.content || ''} placeholder='Content' style={{minHeight: 100}}
                              name='content' onChange={onChangeInputHandler}
                    />
                </Form.Field>
                <Button loading={state.isLoading} type='submit' onClick={handleSubmit}>
                    {state.article ? 'Edit article' : 'Create article'}
                </Button>
            </Form>
        </div>
    );
};

export default ArticleForm;
