import React, {useEffect, useState} from "react";
import './ArticleList.css';
import {API_BASE_URL} from "../../../config";
import {Button, Header, Message} from "semantic-ui-react";
import ArticlesPageTable from "../../../components/ArticlesPageTable/ArticlesPageTable";
import {Link} from "react-router-dom";
import {get, remove} from "../../../services/request";

const ArticleList = () => {
    const [state, setState] = useState({
        articles: null,
        isLoading: false
    });

    const getArticles = () => {
        const token = localStorage.getItem('token');

        try {
            setState(prevState => ({...prevState, isLoading: true}));
            const response = get(API_BASE_URL + "/articles", token);
            response.then(data => setState({articles: data.data, isLoading: false}));
        } catch (e) {
            setState(prevState => ({...prevState, isLoading: false}));
            console.error(e);
        }
    }

    useEffect(() => {
        if (!state.articles) getArticles();
    }, []);

    const handleDelete = (articleId) => {
        setState(prevState => ({...prevState, isLoading: true}));
        const token = localStorage.getItem('token');
        remove(API_BASE_URL + `/articles/${articleId}`, token)
            .then(getArticles)
            .finally(() => setState(prevState => ({...prevState, isLoading: false})));
    };

    return (
        <div>
            <Header as="h1">Articles</Header>
            <div>
                <Button color="blue" as={Link} to='/articles/create'>Create article</Button>
            </div>
            {state.isLoading && <Message info header="Loading articles..." />}
            {
                state.articles && <ArticlesPageTable
                    articles={state.articles}
                    isLoading={state.isLoading}
                    onDeleteHandler={handleDelete}
                />
            }
        </div>
    );
};

export default ArticleList;

