import React, {useEffect, useState} from 'react';
import {get} from "../../../services/request";
import {API_BASE_URL} from "../../../config";
import {Item, Message, Header} from 'semantic-ui-react';
import {useParams} from "react-router-dom";

const ArticleShow  = () => {
    const [state, setState] = useState({
        article: null,
        isLoading: false,
    });

    const {id} = useParams();

    useEffect(() => {
        const token = localStorage.getItem('token');

        if (!state.article) {
            setState(prevState => ({...prevState, isLoading: true}));
            get(API_BASE_URL + `/articles/${id}`, token)
                .then(data => setState(prevState => ({...prevState, article: data.data, isLoading: false})));
        }
    }, [id]);

    return (
        <div>
            {state.isLoading && <Message info header="Loading article..."/>}
            {state.article &&
                <div>
                    <Header as="h1">
                        Article - {state.article.title}
                    </Header>
                    <Item>
                        <Item.Content>
                            <Item.Header as='h3'>{state.article.title}</Item.Header>
                            <Item.Description>
                                <p>{state.article.content}</p>
                            </Item.Description>
                        </Item.Content>
                    </Item>
                </div>
            }
        </div>
    );
};

export default ArticleShow;

