import React, {useEffect, useState} from 'react';
import {Button, Form, Message} from 'semantic-ui-react';
import {API_BASE_URL} from "../../../config";
import {post} from "../../../services/request";
import {useNavigate} from "react-router-dom";
import Errors from "../../../components/Errors/Errors";

const Login = () => {
    const [state, setState] = useState({
        email: null,
        password: null,
        isLoading: false,
        errorMessage: null,
        errors: null,
        error: null
    });
    const navigate = useNavigate();

    useEffect(() => {
        const token = localStorage.getItem('token');
        if (token) {
            navigate("/");
        }
    }, []);

    const handleSubmit = (e) => {
        setState(prevState => ({...prevState, isLoading: true}));
        const data = {
            email: state.email,
            password: state.password
        };
        post(API_BASE_URL + "/login", data)
            .then(response => {
                if (Object.keys(response).includes('token')) {
                    localStorage.setItem('token', response.token);
                    localStorage.setItem('user', JSON.stringify(response.user));
                    return navigate('/');
                } else if (Object.keys(response).includes('error')) {
                    setState(prevState => ({...prevState, error: response.error}));
                }

                setState(prevState => ({
                    ...prevState,
                    errorMessage: response.message,
                    errors: response.errors,
                    isLoading: false
                }));
            });
    };

    const onChangeInputHandler = e => {
        const {name, value} = e.currentTarget;

        setState(prevState => ({
            ...prevState,
            [name]: value,
            errors: null
        }));
    };

    return (
        <div>
            {state.error && <Message negative><Message.Header>{state.error}</Message.Header></Message>}
            {state.errors && <Errors errors={state.errors} errorMessage={state.errorMessage}/>}
            <Form>
                <Form.Field>
                    <label>Email</label>
                    <input type="email" placeholder='Email' name='email' onChange={onChangeInputHandler}/>
                </Form.Field>
                <Form.Field>
                    <label>Password</label>
                    <input type="password" placeholder='Password' name='password' onChange={onChangeInputHandler}/>
                </Form.Field>
                <Button loading={state.isLoading} type='submit' onClick={(event) => handleSubmit(event)}>
                    Login
                </Button>
            </Form>
        </div>
    );
};

export default Login;



