import React, {useEffect, useState} from 'react';
import {Button, Form} from 'semantic-ui-react';
import {API_BASE_URL} from "../../../config";
import {post} from "../../../services/request";
import {useNavigate} from "react-router-dom";
import Errors from "../../../components/Errors/Errors";

const Register = () => {
    const [state, setState] = useState({
        name: null,
        email: null,
        password: null,
        passwordConfirmation: null,
        isLoading: false,
        errors: null
    });
    const navigate = useNavigate();

    useEffect(() => {
        const token = localStorage.getItem('token');
        if (token) {
            navigate("/");
        }
    }, []);

    const handleSubmit = (e) => {
        setState(prevState => ({...prevState, isLoading: true}));
        const data = {
            name: state.name,
            email: state.email,
            password: state.password
        };
        const res = post(API_BASE_URL + "/register", data);
        res.then(response => {
            if (Object.keys(response).includes('token')) {
                localStorage.setItem('token', response.token);
                navigate('/');
            }

            setState(prevState => ({
                ...prevState,
                errorMessage: response.message,
                errors: response.errors,
                isLoading: false
            }));
        });
    };

    const onChangeInputHandler = e => {
        const {name, value} = e.currentTarget;
        console.log(name,value);

        setState(prevState => ({
            ...prevState,
            [name]: value,
            errors: null
        }));
    };

    return (
        <div>
            {state.errors && <Errors errors={state.errors} errorMessage={state.errorMessage}/>}
            <Form>
                <Form.Field>
                    <label>Name</label>
                    <input type="text" placeholder='Name' name='name' onChange={onChangeInputHandler}/>
                </Form.Field>
                <Form.Field>
                    <label>Email</label>
                    <input type="email" placeholder='Email' name='email' onChange={onChangeInputHandler}/>
                </Form.Field>
                <Form.Field>
                    <label>Password</label>
                    <input type="password" placeholder='Password' name='password' onChange={onChangeInputHandler}/>
                </Form.Field>
                <Button loading={state.isLoading} type='submit' onClick={handleSubmit}>
                    Register
                </Button>
            </Form>
        </div>
    );
}

export default Register;

